@@ -1,12 +1,13 @@
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import TYPE_CHECKING, Any, Callable, Optional, Tuple, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Callable, List, Optional, Tuple, TypeVar, cast
 
 from robotcode.core.lsp.types import Position, Range
-from robotcode.language_server.robotframework.utils.ast_utils import Token, range_from_token
+
+from ..utils.ast_utils import Token, range_from_token
 
 if TYPE_CHECKING:
-    from .library_doc import KeywordDoc
+    from .library_doc import KeywordDoc, LibraryDoc
 
 _F = TypeVar("_F", bound=Callable[..., Any])
 
@@ -70,6 +71,20 @@ class Import(SourceEntity):
 class LibraryImport(Import):
     args: Tuple[str, ...] = ()
     alias: Optional[str] = None
+    alias_token: Optional[Token] = None
+
+    @property
+    def alias_range(self) -> Range:
+        return Range(
+            start=Position(
+                line=self.alias_token.lineno - 1 if self.alias_token is not None else -1,
+                character=self.alias_token.col_offset if self.alias_token is not None else -1,
+            ),
+            end=Position(
+                line=self.alias_token.lineno - 1 if self.alias_token is not None else -1,
+                character=self.alias_token.end_col_offset if self.alias_token is not None else -1,
+            ),
+        )
 
     @single_call
     def __hash__(self) -> int:
@@ -152,16 +167,16 @@ class VariableMatcher:
         return self.name
 
     def __repr__(self) -> str:
-        return f"{type(self).__name__}(name={repr(self.name)})"
+        return f"{type(self).__name__}(name={self.name!r})"
 
 
 class VariableDefinitionType(Enum):
-    VARIABLE = "variable"
+    VARIABLE = "suite variable"
     LOCAL_VARIABLE = "local variable"
     ARGUMENT = "argument"
-    COMMAND_LINE_VARIABLE = "command line variable"
+    COMMAND_LINE_VARIABLE = "global variable [command line]"
     BUILTIN_VARIABLE = "builtin variable"
-    IMPORTED_VARIABLE = "imported variable"
+    IMPORTED_VARIABLE = "suite variable [imported]"
     ENVIRONMENT_VARIABLE = "environment variable"
     VARIABLE_NOT_FOUND = "variable not found"
 
@@ -289,3 +304,57 @@ class VariableNotFoundDefinition(VariableDefinition):
     @single_call
     def __hash__(self) -> int:
         return hash((type(self), self.name, self.type))
+
+
+@dataclass
+class LibraryEntry:
+    name: str
+    import_name: str
+    library_doc: "LibraryDoc" = field(compare=False)
+    args: Tuple[Any, ...] = ()
+    alias: Optional[str] = None
+    import_range: Range = field(default_factory=lambda: Range.zero())
+    import_source: Optional[str] = None
+    alias_range: Range = field(default_factory=lambda: Range.zero())
+
+    def __str__(self) -> str:
+        result = self.import_name
+        if self.args:
+            result += f"  {self.args!s}"
+        if self.alias:
+            result += f"  WITH NAME  {self.alias}"
+        return result
+
+    @single_call
+    def __hash__(self) -> int:
+        return hash(
+            (
+                type(self),
+                self.name,
+                self.import_name,
+                self.args,
+                self.alias,
+                self.import_range,
+                self.import_source,
+                self.alias_range,
+            )
+        )
+
+
+@dataclass
+class ResourceEntry(LibraryEntry):
+    imports: List[Import] = field(default_factory=list, compare=False)
+    variables: List[VariableDefinition] = field(default_factory=list, compare=False)
+
+    @single_call
+    def __hash__(self) -> int:
+        return hash((type(self), self.name, self.import_name, self.import_range, self.import_source))
+
+
+@dataclass
+class VariablesEntry(LibraryEntry):
+    variables: List[ImportedVariableDefinition] = field(default_factory=list, compare=False)
+
+    @single_call
+    def __hash__(self) -> int:
+        return hash((type(self), self.name, self.import_name, self.args, self.import_range, self.import_source))
