@@ -9,7 +9,6 @@ import re
 import time
 import weakref
 from collections import OrderedDict
-from dataclasses import dataclass, field
 from itertools import chain
 from pathlib import Path
 from typing import (
@@ -62,13 +61,15 @@ from .entities import (
     CommandLineVariableDefinition,
     EnvironmentVariableDefinition,
     Import,
-    ImportedVariableDefinition,
     InvalidVariableError,
+    LibraryEntry,
     LibraryImport,
     LocalVariableDefinition,
+    ResourceEntry,
     ResourceImport,
     VariableDefinition,
     VariableMatcher,
+    VariablesEntry,
     VariablesImport,
 )
 from .imports_manager import ImportsManager
@@ -416,6 +417,9 @@ class ImportVisitor(Visitor):
         n = cast(RobotLibraryImport, node)
         name = cast(RobotToken, n.get_token(RobotToken.NAME))
 
+        separator = n.get_token(RobotToken.WITH_NAME)
+        alias_token = n.get_tokens(RobotToken.NAME)[-1] if separator else None
+
         last_data_token = cast(
             RobotToken, next(v for v in reversed(n.tokens) if v.type not in RobotToken.NON_DATA_TOKENS)
         )
@@ -426,6 +430,7 @@ class ImportVisitor(Visitor):
                     name_token=name if name is not None else None,
                     args=n.args,
                     alias=n.alias,
+                    alias_token=alias_token,
                     line_no=node.lineno,
                     col_offset=node.col_offset,
                     end_line_no=last_data_token.lineno
@@ -506,36 +511,6 @@ class ImportVisitor(Visitor):
             )
 
 
-@dataclass
-class LibraryEntry:
-    name: str
-    import_name: str
-    library_doc: LibraryDoc
-    args: Tuple[Any, ...] = ()
-    alias: Optional[str] = None
-    import_range: Range = field(default_factory=lambda: Range.zero())
-    import_source: Optional[str] = None
-
-    def __str__(self) -> str:
-        result = self.import_name
-        if self.args:
-            result += f"  {self.args!s}"
-        if self.alias:
-            result += f"  WITH NAME  {self.alias}"
-        return result
-
-
-@dataclass
-class ResourceEntry(LibraryEntry):
-    imports: List[Import] = field(default_factory=list)
-    variables: List[VariableDefinition] = field(default_factory=list)
-
-
-@dataclass
-class VariablesEntry(LibraryEntry):
-    variables: List[ImportedVariableDefinition] = field(default_factory=list)
-
-
 class DocumentType(enum.Enum):
     UNKNOWN = "unknown"
     GENERAL = "robot"
@@ -589,6 +564,7 @@ class Namespace:
         self._diagnostics: List[Diagnostic] = []
         self._keyword_references: Dict[KeywordDoc, Set[Location]] = {}
         self._variable_references: Dict[VariableDefinition, Set[Location]] = {}
+        self._namespace_references: Dict[LibraryEntry, Set[Location]] = {}
 
         self._imported_keywords: Optional[List[KeywordDoc]] = None
         self._imported_keywords_lock = Lock()
@@ -705,6 +681,7 @@ class Namespace:
         self._diagnostics = []
         self._keyword_references = {}
         self._variable_references = {}
+        self._namespace_references = {}
         self._finder = None
         self._in_initialize = False
         self._ignored_lines = None
@@ -740,6 +717,18 @@ class Namespace:
 
         return self._variable_references
 
+    async def get_namespace_references(self) -> Dict[LibraryEntry, Set[Location]]:
+        await self.ensure_initialized()
+
+        await self._analyze()
+
+        return self._namespace_references
+
+    async def get_import_entries(self) -> OrderedDict[Import, LibraryEntry]:
+        await self.ensure_initialized()
+
+        return self._import_entries
+
     @_logger.call
     async def get_libraries(self) -> OrderedDict[str, LibraryEntry]:
         await self.ensure_initialized()
@@ -965,11 +954,11 @@ class Namespace:
             await self.get_global_variables(),
         ):
             if var.matcher not in yielded.keys():
-                yielded[var.matcher] = var
-
                 if skip_commandline_variables and isinstance(var, CommandLineVariableDefinition):
                     continue
 
+                yielded[var.matcher] = var
+
                 yield var.matcher, var
 
     async def get_resolvable_variables(
@@ -1045,6 +1034,7 @@ class Namespace:
                     )
                     result.import_range = value.range
                     result.import_source = value.source
+                    result.alias_range = value.alias_range
 
                     self._import_entries[value] = result
 
@@ -1593,6 +1583,7 @@ class Namespace:
                     self._diagnostics += result.diagnostics
                     self._keyword_references = result.keyword_references
                     self._variable_references = result.variable_references
+                    self._namespace_references = result.namespace_references
 
                     lib_doc = await self.get_library_doc()
 
@@ -1700,6 +1691,7 @@ class KeywordFinder:
         self.self_library_doc = library_doc
 
         self.diagnostics: List[DiagnosticsEntry] = []
+        self.multiple_keywords_result: Optional[Sequence[Tuple[Optional[LibraryEntry], KeywordDoc]]] = None
         self._cache: Dict[Tuple[Optional[str], bool], Tuple[Optional[KeywordDoc], List[DiagnosticsEntry]]] = {}
         self.handle_bdd_style = True
         self._all_keywords: Optional[List[LibraryEntry]] = None
@@ -1708,6 +1700,7 @@ class KeywordFinder:
 
     def reset_diagnostics(self) -> None:
         self.diagnostics = []
+        self.multiple_keywords_result = None
 
     def find_keyword(
         self, name: Optional[str], *, raise_keyword_error: bool = False, handle_bdd_style: bool = True
@@ -1852,6 +1845,8 @@ class KeywordFinder:
     def _create_multiple_keywords_found_message(
         self, name: str, found: Sequence[Tuple[Optional[LibraryEntry], KeywordDoc]], implicit: bool = True
     ) -> str:
+        self.multiple_keywords_result = found
+
         if any(e[1].is_embedded for e in found):
             error = f"Multiple keywords matching name '{name}' found"
         else:
