@@ -34,6 +34,7 @@ from robotcode.core.lsp.types import (
 )
 from robotcode.language_server.common.decorators import language_id
 from robotcode.language_server.common.text_document import TextDocument, range_to_utf16
+from robotcode.language_server.robotframework.diagnostics.entities import LibraryEntry, ResourceEntry
 from robotcode.language_server.robotframework.diagnostics.library_doc import (
     ALL_RUN_KEYWORDS_MATCHERS,
     BUILTIN_LIBRARY_NAME,
@@ -44,9 +45,7 @@ from robotcode.language_server.robotframework.diagnostics.library_doc import (
 )
 from robotcode.language_server.robotframework.diagnostics.namespace import (
     DEFAULT_BDD_PREFIXES,
-    LibraryEntry,
     Namespace,
-    ResourceEntry,
 )
 from robotcode.language_server.robotframework.utils import async_ast
 from robotcode.language_server.robotframework.utils.ast_utils import (
@@ -278,7 +277,6 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
     ) -> AsyncIterator[SemTokenInfo]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import (
-            Arguments,
             Documentation,
             Fixture,
             LibraryImport,
@@ -310,7 +308,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
                         yield SemTokenInfo.from_token(
                             token,
-                            SemanticTokenTypes.PARAMETER if isinstance(node, Arguments) else sem_type,
+                            sem_type,
                             sem_mod,
                             col_offset + 2,
                             last_index - 2,
@@ -498,24 +496,46 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         resources_matchers: Dict[KeywordMatcher, ResourceEntry],
     ) -> AsyncIterator[SemTokenInfo]:
         from robot.parsing.lexer.tokens import Token as RobotToken
-        from robot.parsing.model.statements import Variable
+        from robot.parsing.model.statements import Arguments, Variable
         from robot.utils.escaping import split_from_equals
 
         if token.type in {RobotToken.ARGUMENT, RobotToken.TESTCASE_NAME, RobotToken.KEYWORD_NAME}:
-            if isinstance(node, Variable) and token.type == RobotToken.ARGUMENT and node.name and node.name[0] == "&":
+            if (
+                isinstance(node, Variable) and token.type == RobotToken.ARGUMENT and node.name and node.name[0] == "&"
+            ) or (isinstance(node, Arguments)):
                 name, value = split_from_equals(token.value)
                 if value is not None:
                     length = len(name)
 
                     yield SemTokenInfo.from_token(
-                        RobotToken(ROBOT_NAMED_ARGUMENT, name, token.lineno, token.col_offset),
-                        RobotSemTokenTypes.NAMED_ARGUMENT,
+                        RobotToken(
+                            ROBOT_NAMED_ARGUMENT if isinstance(node, Variable) else SemanticTokenTypes.PARAMETER,
+                            name,
+                            token.lineno,
+                            token.col_offset,
+                        ),
+                        RobotSemTokenTypes.NAMED_ARGUMENT
+                        if isinstance(node, Variable)
+                        else SemanticTokenTypes.PARAMETER,
                     )
                     yield SemTokenInfo.from_token(
                         RobotToken(ROBOT_OPERATOR, "=", token.lineno, token.col_offset + length),
                         SemanticTokenTypes.OPERATOR,
                     )
                     token = RobotToken(token.type, value, token.lineno, token.col_offset + length + 1, token.error)
+                elif isinstance(node, Arguments) and name:
+                    yield SemTokenInfo.from_token(
+                        RobotToken(
+                            ROBOT_NAMED_ARGUMENT if isinstance(node, Variable) else SemanticTokenTypes.PARAMETER,
+                            name,
+                            token.lineno,
+                            token.col_offset,
+                        ),
+                        RobotSemTokenTypes.NAMED_ARGUMENT
+                        if isinstance(node, Variable)
+                        else SemanticTokenTypes.PARAMETER,
+                    )
+                    token = RobotToken(token.type, "", token.lineno, token.col_offset + len(name), token.error)
 
             for sub_token in self._tokenize_variables(
                 token,
@@ -770,7 +790,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         async def get_tokens() -> AsyncIterator[Tuple[Token, ast.AST]]:
             async for node in async_ast.iter_nodes(model):
                 if isinstance(node, HasTokens):
-                    if isinstance(node, LibraryImport):
+                    if isinstance(node, LibraryImport) and node.name:
                         lib_doc = await namespace.get_imported_library_libdoc(node.name, node.args, node.alias)
                         kw_doc = lib_doc.inits.keywords[0] if lib_doc and lib_doc.inits else None
                         if lib_doc is not None:
@@ -807,7 +827,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
                                 yield token, node
                             continue
-                    if isinstance(node, VariablesImport):
+                    if isinstance(node, VariablesImport) and node.name:
                         lib_doc = await namespace.get_imported_variables_libdoc(node.name, node.args)
                         kw_doc = lib_doc.inits.keywords[0] if lib_doc and lib_doc.inits else None
                         if lib_doc is not None:
